.. tendo documentation master file, created by
   sphinx-quickstart on Thu Aug  4 16:26:14 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tendo's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2

=========
singleton
=========
.. automodule:: tendo.singleton

.. autoclass:: SingleInstance
    :members: 

=======
colorer
=======
.. automodule:: tendo.colorer

=======
unicode
=======
.. automodule:: tendo.unicode

.. autofunction:: open

=======
tee
=======
.. automodule:: tendo.tee

.. autofunction:: system
.. autofunction:: system2

=========
execfile2
=========
.. automodule:: tendo.execfile2
.. autofunction:: execfile2


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

